==> disco_stu-1.3.4-py27_0.tar.bz2: lib/python2.7/site-packages/disco_stu/disco_stu.py <==
import numpy as np
import sys
from collections import namedtuple
from .disco import disco
from .bookkeeping.log_utilities import get_logger, configure_log
from .lookups import general_parameters as params

global log

def disco_stu(args):
    #args = parse_command_line()
    log = get_logger(args.logfile)
    log.info("Disco-Stu will reduce your data for you.")
    
    MatchInfo = namedtuple('MatchInfo', ['offset_radius', 'match_radius',
                                         'min_matches', 'degree'])
    
    # Make the cleaning footprint
    if args.clean_radius>=1:
        half_size = np.floor(args.clean_radius)
        rdistsq = np.sum(np.mgrid[-half_size:half_size+1,
                                  -half_size:half_size+1]**2,axis=0)
        clean_footprint = np.where(rdistsq>args.clean_radius**2, 0, 1)
        clean_footprint[half_size,half_size] = 0
    else:
        clean_footprint = None
    
    # And... DISCO!
    disco(args.input_files,
           output_identifier=args.output,
           objmatch_info=MatchInfo(params.OBJCAT_ALIGN_RADIUS[0],
                              params.OBJCAT_ALIGN_RADIUS[1],
                              None,args.degree),
           refmatch_info=MatchInfo(args.search_radius[0],args.search_radius[1],
                              args.min_matches,params.REFCAT_POLY_DEGREE),
           static_transform=True,
           ignore_objcat=args.ignore_objcat,
           refcat=args.refcat,
           skysub=not args.no_skysub,
           stack=not args.no_stack,
           align=not args.no_align,
           combine_type=args.combine,
           donor_wcs=args.wcs,
           final_pa=args.pa,
           pixel_scale=args.pixel_scale,
           parallel=not args.serial,
           clean_iter=args.clean_iter,
           clean_footprint=clean_footprint)
    
    log.info("Please enjoy your data responsibly.")

==> disco_stu-1.3.6-py36_0.tar.bz2: lib/python3.6/site-packages/disco_stu/disco_stu.py <==
import numpy as np
from collections import namedtuple
from .disco import disco
from .bookkeeping.log_utilities import get_logger, configure_log
from .lookups import general_parameters as params

global log

def disco_stu(args):
    log = get_logger(args.logfile)
    log.info("Disco-Stu will reduce your data for you.")
    
    MatchInfo = namedtuple('MatchInfo', ['offset_radius', 'match_radius',
                                         'min_matches', 'degree'])
    
    # Make the cleaning footprint
    if args.clean_radius>=1:
        half_size = int(args.clean_radius)
        rdistsq = np.sum(np.mgrid[-half_size:half_size+1,
                                  -half_size:half_size+1]**2,axis=0)
        clean_footprint = np.where(rdistsq>args.clean_radius**2, 0, 1)
        clean_footprint[half_size,half_size] = 0
    else:
        clean_footprint = None
    
    # And... DISCO!
    disco(args.input_files,
           output_identifier=args.output,
           objmatch_info=MatchInfo(params.OBJCAT_ALIGN_RADIUS[0],
                              params.OBJCAT_ALIGN_RADIUS[1],
                              None,args.degree),
           refmatch_info=MatchInfo(args.search_radius[0],args.search_radius[1],
                              args.min_matches,params.REFCAT_POLY_DEGREE),
           static_transform=True,
           ignore_objcat=args.ignore_objcat,
           refcat=args.refcat,
           skysub=not args.no_skysub,
           stack=not args.no_stack,
           align=not args.no_align,
           combine_type=args.combine,
           reference_image=args.reference,
           donor_wcs=args.wcs,
           final_pa=args.pa,
           pixel_scale=args.pixel_scale,
           parallel=not args.serial,
           clean_iter=args.clean_iter,
           clean_footprint=clean_footprint)
    
    log.info("Please enjoy your data responsibly.")
